@@ -2,16 +2,15 @@
 # -*-coding:utf-8 -*-
 # Author     ：Campanula 梦芸 何
 import asyncio
-from typing import Iterable
+from typing import Iterable, List, Union, Tuple, Any
 
 import aiomysql
 from aiomysql import DictCursor
 
-
-from anduin.common import dbg, get_obj_name
 from anduin.common import ENGINE_MYSQL
-from anduin.parser.sql_parser import Parser
+from anduin.common import dbg, get_obj_name
 from anduin.frames.client_base import ClientBase
+from anduin.parser.sql_parser import Parser
 
 
 # from pymysql.cursors import DictCursor
@@ -23,25 +22,23 @@ class AsyncMySQLClient(ClientBase):
         self.db = None
         self._tables = {}
 
-
     async def connect_db(self):
         try:
             res = await aiomysql.connect(host=self._host, user=self._user, password=self._psw, db=self._dbname,
-                                     charset=self._charset, port=self._port)
-        # dbg('连接成功',type(res))
+                                         charset=self._charset, port=self._port, connect_timeout=self.time_out)
+            # dbg('连接成功',type(res))
             dbg('连接创建成功', get_obj_name(self))
             self.db = res
             return res
         except Exception as e:
-            dbg('连接创建失败',e,get_obj_name(self))
+            dbg('连接创建失败', e, get_obj_name(self))
             return
 
-
     async def load_an_table(self, tablename):
-        sql = 'show fields from ' + tablename
+        sql = 'show fields from ' + tablename +''
         res = await self.query(sql, show_sql=False)
-        if isinstance(res,Iterable):
-            self._tables[tablename] = dict(zip(list(map(lambda x: x[0],res)),res))
+        if isinstance(res, Iterable):
+            self._tables[tablename] = dict(zip(list(map(lambda x: x[0], res)), res))
         return res
 
     async def _load_tables(self, show_sql=False):
@@ -49,7 +46,10 @@ class AsyncMySQLClient(ClientBase):
         res = await self.query(sql, show_sql)
         tables = list(map(lambda x: x[0], res))
         for table in tables:
-            table_name = self._dbname + '.' + table
+            if '-' not in self._dbname:
+                table_name = self._dbname + '.' + table
+            else:
+                table_name = table
             await self.load_an_table(table_name)
 
     async def release_lock(self):
@@ -60,7 +60,14 @@ class AsyncMySQLClient(ClientBase):
         await self.db.commit()
 
     async def query(self, sql: str, show_sql=None, sql_params=None, return_dict=False):
-        dummy_sql = sql % tuple(sql_params) if sql_params is not None else sql
+        if sql_params is not None:
+            tmp = []
+            for i in sql_params:
+                tmp.append('"' + str(i) + '"')
+            dummy_sql = sql % tuple(tmp)
+        else:
+            dummy_sql = sql
+
         if return_dict is True:
             cursor = await self.db.cursor(DictCursor)
         else:
@@ -69,7 +76,7 @@ class AsyncMySQLClient(ClientBase):
             dbg('sql_id', id(self), dummy_sql)
         try:
             if sql_params is not None:
-                await cursor.execute(sql,tuple(sql_params))
+                await cursor.execute(sql, tuple(sql_params))
             else:
                 await cursor.execute(sql)
             self.update_last_execute_time()
@@ -94,7 +101,7 @@ class AsyncMySQLClient(ClientBase):
             await self.load_an_table(table)
 
         if fields[0] == '*' and len(fields) == 1:
-            fieldList = self._tables[table]
+            fieldList = list(self._tables[table].keys())
             fields = fieldList
 
         sql, sql_params = Parser.find_info(table, conditions, or_cond, fields, None, order, None, for_update)
@@ -120,6 +127,10 @@ class AsyncMySQLClient(ClientBase):
         if table not in self._tables:
             await self.load_an_table(table)
 
+        if fields[0] == '*' and len(fields) == 1:
+            fieldList = list(self._tables[table].keys())
+            fields = fieldList
+
         sql, sql_params = Parser.find_info(table, conditions, or_cond, fields, group, order, limit, for_update)
         if sql is None:
             return
@@ -145,9 +156,24 @@ class AsyncMySQLClient(ClientBase):
         # dbg('自动提交完毕')
         return r
 
-    async def delete(self, table, condition, or_cond=None, show_sql=False):
+    async def delete(self, table: str, conditions: List[Tuple], or_cond: Union[List[Tuple], None] = None, show_sql: bool = False):
+        '''
+        删除数据
+        :params
+            conditions: 通过and连接的条件
+            [
+                 ('id', '=', 1)
+                 ('status', '!=', 1)
+            ]
+            or_cond: 通过or连接的条件
+            [
+                ('id', '=', 1)
+                ('status', '!=', 1)
+            ]
+            show_sql: 是否展示本次sql
+        '''
         sql = 'delete from %s where  ' % table
-        sql, sql_params = Parser.bind_conditions(sql, condition, or_cond)
+        sql, sql_params = Parser.bind_conditions(sql, conditions, or_cond)
         #  #
         r = await self.query(sql, show_sql, sql_params)
         return r
@@ -155,9 +181,19 @@ class AsyncMySQLClient(ClientBase):
     def show_database(self):
         return self._tables
 
+    async def drop_table(self,tablename:str,show_sql=False):
+        '''
+        删除数据表
+        '''
+        sql = 'drop table if exists %s'%tablename
+        r = await self.query(sql,show_sql=show_sql)
+        return r
+
 
 if __name__ == '__main__':
     async def get_data():
         return 'xxx'
+
+
     r = asyncio.run(get_data())
-    print(r)
\ No newline at end of file
+    print(r)
