@@ -3,15 +3,16 @@
 # Author     ：Campanula 梦芸 何
 import time
 
-from anduin.common import ENGINE_SQLITE,get_db_index,dbg
+from anduin.common import ENGINE_SQLITE, get_db_index, dbg
 from anduin.db.sql.sqlite.db_client import SQLiteClient
-from anduin.frames.manager_base import ManagerBase, TIMEOUT
+from anduin.frames.manager_base import ManagerBase
 
 
 class SQLiteManager(ManagerBase):
     def __init__(self, config):
         super().__init__(config)
 
+
     def create_connection(self):
         dbg('无可用空闲链接，创建链接...', get_db_index(self.t_data))
         db_client = SQLiteClient(self.host, self.user, self.password, None, self.database, ENGINE_SQLITE, self.charset)
@@ -26,7 +27,7 @@ class SQLiteManager(ManagerBase):
         cur_time = int(time.time())
         my_pool = self.get_cur_client_pool_by_thread_id()
         for sid, client in my_pool.items():
-            if cur_time - client.last_connect_time < TIMEOUT:
+            if cur_time - client.last_connect_time < client.time_out:
                 if client.is_lock is False:
                     my_client = client
                     break
